---
---

// Convert query arguments to object
// @see {https://stackoverflow.com/a/7090123}
// @return [Object]
const searchToObject = () => {
  var pairs = window.location.search.substring(1).split("&"),
    obj = {},
    pair,
    i;

  for (i in pairs) {
    if (pairs[i] === "") continue;

    pair = pairs[i].split("=");
    obj[decodeURIComponent(pair[0])] = decodeURIComponent(pair[1]);
  }

  return obj;
}

// Compatible with Turbolinks
const loadEvent = () => window.Turbolinks ? 'turbolinks:load' : 'DOMContentLoaded';

document.addEventListener(loadEvent(), () => {
  const urlShared = searchToObject();

  // Add the query args to the locale selector
  document.querySelectorAll('a[lang]').forEach(a => a.href += window.location.search);

  // Recover data from URL only if it's set
  ['t','d','u'].forEach(field => {
    if (urlShared[field] === undefined) return;

    document.querySelector(`#${field}`).innerText = urlShared[field];
  });

  // Send this field
  document.querySelector('#text').value = Object.values(urlShared).join("\n\n");

  // Helpers for data storage
  const isCheckbox = input => input.type == 'checkbox';
  const itemId = (form, input) => form.id + ':' + input.id;

  const form = document.querySelector('form')
  const formInputs = Array.from(form.elements);

  form.addEventListener('submit', e => {
    // Change the form action to the actual instance
    form.action = document.querySelector('#instance').value + '/share';

    const rememberInstance = document.querySelector('#remember').checked;

    // If user disabled it, forget data.
    if (!rememberInstance) localStorage.clear();

    // Store the data.  Form autocomplete should be helpful
    // here but for some reason it doesn't.
    formInputs.forEach(input => {
      if (input.type == 'submit') return;

      if (!rememberInstance) return;

      localStorage.setItem(itemId(form, input), isCheckbox(input) ? input.checked : input.value);
    });
  });

  // Recover information
  formInputs.forEach(input => {
    if (input.type == 'submit') return;

    const value = localStorage.getItem(itemId(form, input));

    if (value) input[isCheckbox(input) ? 'checked' : 'value'] = value;
  });

  // Redirect after a timeout, so users have time to disable.
  setTimeout(() => {
    if (!document.querySelector('#remember').checked) return;
    document.querySelector('form').submit();
  }, {{ site.auto_submit_seconds | default: 3 }} * 1000);
});
